@@ -532,6 +532,8 @@ brasero_utils_disc_hide_use_info_data_received_cb (GtkWidget *widget,
 {
 	GtkWidget *other_widget;
 
+	g_return_if_fail(BRASERO_IS_PROJECT(project));
+
 	other_widget = brasero_utils_disc_find_tree_view (project->priv->current);
 	if (!other_widget)
 		return;
@@ -2338,7 +2340,7 @@ brasero_project_register_ui (BraseroProject *project, GtkUIManager *manager)
 
 	project->priv->manager = manager;
 
-	if (GTK_WIDGET_REALIZED (project->priv->name_display))
+	if (gtk_widget_get_realized (project->priv->name_display))
 		gtk_widget_grab_focus (project->priv->name_display);
 }
 
